@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkOutEdgeIterator extends vtkObject
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -25,7 +25,7 @@ public class vtkOutEdgeIterator extends vtkObject
 
     if (temp == 0) return null;
     return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native int GetVertex_4();
   public int GetVertex()
@@ -37,7 +37,7 @@ public class vtkOutEdgeIterator extends vtkObject
 
     if (temp == 0) return null;
     return (vtkGraphEdge)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native boolean HasNext_6();
   public boolean HasNext()
